@@ -23,13 +23,6 @@ pub fn build(build_config: core::BuildConfig) -> Result<core::BuildResult, core:
     let rev = build_config.get_revision()?;
     let target = local_target();
 
-    // TODO(@jroesch): map this to target triple based target directory
-    // should probably be target + host + profile.
-    match build_config.output_path {
-        None => (),
-        _ => panic!("this option is currently disabled"),
-    };
-
     rev.build_for(&build_config, target)?;
 
     // info!(target = target.target_str);
@@ -38,14 +31,15 @@ pub fn build(build_config: core::BuildConfig) -> Result<core::BuildResult, core:
     Ok(core::BuildResult { revision: rev })
 }
 
-pub fn uninstall(revision: String) -> Result<(), core::Error> {
-    let directory = core::tvm_build_directory().join(revision);
+pub fn uninstall(revision: String, output_path: Option<String>) -> Result<(), core::Error> {
+    let revision = Revision::new(revision, output_path);
+    let directory = revision.path();
     std::fs::remove_dir(directory)?;
     Ok(())
 }
 
 pub fn version_config(revision: String) -> Result<VersionConfig, core::Error> {
-    let rev = Revision::new(revision);
+    let rev = Revision::new(revision, None);
     let version = VersionConfig {
         tvm_python_path: rev.source_path().join("python").join("tvm"),
     };
